require('runtime-adapter/ral.js');
require('runtime-adapter/web-adapter.js');


// Polyfills bundle.
require("src/polyfills.bundle.js");


// SystemJS support.
window.self = window;
require("src/system.bundle.js");

const importMapJson = ral.getFileSystemManager().readFileSync("src/import-map.json", 'utf8');
const importMap = JSON.parse(importMapJson);
System.warmup({
    importMap,
    importMapUrl: 'src/import-map.json',
    defaultHandler: (urlNoSchema) => {
        require('.' + urlNoSchema);
    },
});

System.import('./application.js').then(({ createApplication }) => {
    return createApplication({
        loadJsListFile: (url) => require(`./${url}`),
        fetchWasm: (url) => url,
    });
}).then((application) => {
    return onApplicationCreated(application);
}).catch((err) => {
    console.error(err);
});

function onApplicationCreated(application) {
    return application.import('cc').then((cc) => {
        require('runtime-adapter/engine-adapter.js');
        cc.macro.CLEANUP_IMAGE_CACHE = false;
        return application.start({
            findCanvas: () => {
                var container = document.createElement('div');
                var frame = container.parentNode === document.body ? document.documentElement : container.parentNode;
                var canvas = ral.createCanvas();
                return { frame, canvas, container };
            },
        });
    });
}
